@@ -12,7 +12,7 @@ use std::sync::Arc;
 use std::time::Duration;
 
 use super::Semphore;
-use crossbeam::queue::SegQueue;
+use crate::std::queue::seg_queue::SegQueue;
 
 /// Create an unbounded channel. if If you want to limit the number of messages, use bounded channel_buf()
 pub fn channel<T>() -> (Sender<T>, Receiver<T>) {
@@ -37,10 +37,18 @@ pub fn bounded<T>(buf: usize) -> (Sender<T>, Receiver<T>) {
 
 /// create an channel(mpmc)
 ///  for example:
+/// ```
+///   use cogo::chan;
 ///   //bounded
 ///   let (sender, receiver) = chan!(2);
+///   sender.send(1);//send msg
+///   let rv=receiver.recv(); //recv msg
 ///   //unbounded
 ///   let (sender, receiver) = chan!();
+///   sender.send(1);
+///   let rv=receiver.recv();
+///
+/// ```
 #[macro_export]
 macro_rules! chan {
     () => {
