@@ -76,7 +76,7 @@ impl<T: ?Sized> Mutex<T> {
                 Ok(_) => {
                     break;
                 }
-                Err(ParkError::Timeout) => unreachable!("mutext timeout"),
+                Err(ParkError::Timeout) => unreachable!("mutex timeout"),
                 Err(ParkError::Canceled) => {
                     let b_ignore = if crate::coroutine_impl::is_coroutine() {
                         let cancel = crate::coroutine_impl::current_cancel_data();
@@ -141,8 +141,7 @@ impl<T: ?Sized> Mutex<T> {
         if self.cnt.fetch_sub(1, Ordering::SeqCst) > 1 {
             self.to_wake
                 .pop()
-                .map(|w| self.unpark_one(&w))
-                .expect("got null blocker!");
+                .map(|w| self.unpark_one(&w));
         }
     }
 
@@ -539,7 +538,7 @@ mod tests {
 
         let h1 = go!(move || {
             let mut g = mutex2.lock().unwrap();
-            // test cancel when holding the mutext
+            // test cancel when holding the mutex
             // this should not be poision
             sleep(Duration::from_secs(10000));
             *g += 1;
